==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/IpFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs.builder
import com.pulumi.azurenative.devices.kotlin.enums.IpFilterActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The IP filter rules for the IoT hub.
 * @property action The desired action for requests captured by this rule.
 * @property filterName The name of the IP filter rule.
 * @property ipMask A string that contains the IP address range in CIDR notation for the rule.
 */
public data class IpFilterRuleArgs(
    public val action: Output<IpFilterActionType>,
    public val filterName: Output<String>,
    public val ipMask: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs =
        com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs.builder()
            .action(action.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .filterName(filterName.applyValue({ args0 -> args0 }))
            .ipMask(ipMask.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpFilterRuleArgs].
 */
@PulumiTagMarker
public class IpFilterRuleArgsBuilder internal constructor() {
    private var action: Output<IpFilterActionType>? = null

    private var filterName: Output<String>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The desired action for requests captured by this rule.
     */
    @JvmName("jmeneorwmhxcteaw")
    public suspend fun action(`value`: Output<IpFilterActionType>) {
        this.action = value
    }

    /**
     * @param value The name of the IP filter rule.
     */
    @JvmName("cuxgsdmpivrsndcv")
    public suspend fun filterName(`value`: Output<String>) {
        this.filterName = value
    }

    /**
     * @param value A string that contains the IP address range in CIDR notation for the rule.
     */
    @JvmName("uredaalvcsfunhae")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The desired action for requests captured by this rule.
     */
    @JvmName("qbihhhehudqignok")
    public suspend fun action(`value`: IpFilterActionType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The name of the IP filter rule.
     */
    @JvmName("flwamtqyumrufgde")
    public suspend fun filterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterName = mapped
    }

    /**
     * @param value A string that contains the IP address range in CIDR notation for the rule.
     */
    @JvmName("vbjuflmslqboeypd")
    public suspend fun ipMask(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): IpFilterRuleArgs = IpFilterRuleArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        filterName = filterName ?: throw PulumiNullFieldException("filterName"),
        ipMask = ipMask ?: throw PulumiNullFieldException("ipMask"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/IpFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs.builder
import com.pulumi.azurenative.devices.kotlin.enums.IpFilterActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The IP filter rules for the IoT hub.
 * @property action The desired action for requests captured by this rule.
 * @property filterName The name of the IP filter rule.
 * @property ipMask A string that contains the IP address range in CIDR notation for the rule.
 */
public data class IpFilterRuleArgs(
    public val action: Output<IpFilterActionType>,
    public val filterName: Output<String>,
    public val ipMask: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs =
        com.pulumi.azurenative.devices.inputs.IpFilterRuleArgs.builder()
            .action(action.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .filterName(filterName.applyValue({ args0 -> args0 }))
            .ipMask(ipMask.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IpFilterRuleArgs].
 */
@PulumiTagMarker
public class IpFilterRuleArgsBuilder internal constructor() {
    private var action: Output<IpFilterActionType>? = null

    private var filterName: Output<String>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The desired action for requests captured by this rule.
     */
    @JvmName("tihhbqskcbpspioi")
    public suspend fun action(`value`: Output<IpFilterActionType>) {
        this.action = value
    }

    /**
     * @param value The name of the IP filter rule.
     */
    @JvmName("mmfxsymcthurlmca")
    public suspend fun filterName(`value`: Output<String>) {
        this.filterName = value
    }

    /**
     * @param value A string that contains the IP address range in CIDR notation for the rule.
     */
    @JvmName("oefpsdpflbddmwnj")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The desired action for requests captured by this rule.
     */
    @JvmName("vkxeotputdvlbdon")
    public suspend fun action(`value`: IpFilterActionType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The name of the IP filter rule.
     */
    @JvmName("ysbwghpkqqukvkdx")
    public suspend fun filterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filterName = mapped
    }

    /**
     * @param value A string that contains the IP address range in CIDR notation for the rule.
     */
    @JvmName("uucbprpfidllmmtc")
    public suspend fun ipMask(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): IpFilterRuleArgs = IpFilterRuleArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        filterName = filterName ?: throw PulumiNullFieldException("filterName"),
        ipMask = ipMask ?: throw PulumiNullFieldException("ipMask"),
    )
}
